@@ -19,7 +19,7 @@ from constructor.exceptions import (
 )
 
 
-PREABLE = '''\n
+PREAMBLE = '''\n
 Keys in `construct.yaml` file:
 ==============================
 
@@ -56,9 +56,10 @@ given in the `packages` list (see below).
 '''),
 
     ('channels_remap',         False, list, '''
-List of (src, dest) channels, from which, channels from 'src' are also
+List of `(src, dest)` channels, from which, channels from `src` are also
 considered while running solver, but are replaced by corresponding values from
-dest when writing urls{,.txt}. Example use:
+dest when writing `urls{,.txt}`. Example use:
+```
 channels_remap:
   -
       src: file:///tmp/a3/conda-bld
@@ -66,6 +67,7 @@ channels_remap:
   -
       src: file:///tmp/r/conda-bld
       dest: https://repo.continuum.io/pkgs/r
+```
 '''),
 
     ('specs',                  False, (list, str), '''
@@ -318,7 +320,7 @@ def generate_doc():
     path = abspath('%s/../../CONSTRUCT.md' % __file__)
     print('generating: %s' % path)
     with open(path, 'w') as fo:
-        fo.write(PREABLE)
+        fo.write(PREAMBLE)
         for key, required, unused_types, descr in KEYS:
             descr = descr.strip()
             if descr == 'XXX':
@@ -331,6 +333,13 @@ def generate_doc():
 """ % (key,
        ' required' if required else '',
        descr))
+        fo.write("""
+List of platform selectors:
+==============================
+```
+%s
+```
+""" % ('\n'.join(ns_platform('').keys())))
 
 
 if __name__ == '__main__':
